@@ -60,29 +60,31 @@
 #'
 #' @examples
 #' \donttest{
-#' #priors
-#' p_prior <- b_prior(family="beta", pars=c(1, 1))
-#' tau_prior <- b_prior(family="uniform", pars=c(0, 500))
+#' # priors
+#' p_prior <- b_prior(family = "beta", pars = c(1, 1))
+#' tau_prior <- b_prior(family = "uniform", pars = c(0, 500))
 #'
 #' # attach priors to relevant parameters
-#' priors <- list(c("p", p_prior),
-#'                c("tau", tau_prior))
+#' priors <- list(
+#'   c("p", p_prior),
+#'   c("tau", tau_prior)
+#' )
 #'
 #' # subjects
 #' s <- rep(1:5, 20)
 #'
 #' # generate data and fit
-#' data1 <- rbinom(100, size=1, prob=0.6)
-#' fit1 <- b_success_rate(r=data1, s=s, priors=priors, chains=1)
+#' data1 <- rbinom(100, size = 1, prob = 0.6)
+#' fit1 <- b_success_rate(r = data1, s = s, priors = priors, chains = 1)
 #'
-#' data2 <- rbinom(100, size=1, prob=0.1)
-#' fit2 <- b_success_rate(r=data2, s=s, priors=priors, chains=1)
+#' data2 <- rbinom(100, size = 1, prob = 0.1)
+#' fit2 <- b_success_rate(r = data2, s = s, priors = priors, chains = 1)
 #'
-#' data3 <- rbinom(100, size=1, prob=0.5)
-#' fit3 <- b_success_rate(r=data3, s=s, priors=priors, chains=1)
+#' data3 <- rbinom(100, size = 1, prob = 0.5)
+#' fit3 <- b_success_rate(r = data3, s = s, priors = priors, chains = 1)
 #'
-#' data4 <- rbinom(100, size=1, prob=0.9)
-#' fit4 <- b_success_rate(r=data4, s=s, priors=priors, chains=1)
+#' data4 <- rbinom(100, size = 1, prob = 0.9)
+#' fit4 <- b_success_rate(r = data4, s = s, priors = priors, chains = 1)
 #'
 #' # fit list
 #' fit_list <- list(fit2, fit3, fit4)
@@ -100,8 +102,8 @@
 #'
 #' # plot the fitted distribution against the data,
 #' # plot on the top (group) level
-#' plot(fit1, subjects=FALSE)
-#' plot_fit(fit1, subjects=FALSE)
+#' plot(fit1, subjects = FALSE)
+#' plot_fit(fit1, subjects = FALSE)
 #'
 #' # traceplot of the fitted parameters
 #' plot_trace(fit1)
@@ -113,49 +115,49 @@
 #' subject_parameters <- get_subject_parameters(fit1)
 #'
 #' # compare means between two fits, use a rope interval
-#' compare_means(fit1, fit2=fit2, rope=0.05)
+#' compare_means(fit1, fit2 = fit2, rope = 0.05)
 #'
 #' # compare means between multiple fits
-#' compare_means(fit1, fits=fit_list)
+#' compare_means(fit1, fits = fit_list)
 #'
 #' # visualize difference in means between two fits,
 #' # specify number of histogram bins and rope interval
-#' plot_means_difference(fit1, fit2=fit2, bins=40, rope=0.05)
+#' plot_means_difference(fit1, fit2 = fit2, bins = 40, rope = 0.05)
 #'
 #' # visualize difference in means between multiple fits
-#' plot_means_difference(fit1, fits=fit_list)
+#' plot_means_difference(fit1, fits = fit_list)
 #'
 #' # visualize means of a single fit
 #' plot_means(fit1)
 #'
 #' # visualize means of two fits
-#' plot_means(fit1, fit2=fit2)
+#' plot_means(fit1, fit2 = fit2)
 #'
 #' # visualize means of multiple fits
-#' plot_means(fit1, fits=fit_list)
+#' plot_means(fit1, fits = fit_list)
 #'
 #' # draw samples from distributions underlying two fits and compare them,
 #' # use a rope interval
-#' compare_distributions(fit1, fit2=fit2, rope=0.05)
+#' compare_distributions(fit1, fit2 = fit2, rope = 0.05)
 #'
 #' # draw samples from distributions underlying multiple fits and compare them
-#' compare_distributions(fit1, fits=fit_list)
+#' compare_distributions(fit1, fits = fit_list)
 #'
 #' # visualize the distribution underlying a fit
 #' plot_distributions(fit1)
 #'
 #' # visualize distributions underlying two fits
-#' plot_distributions(fit1, fit2=fit2)
+#' plot_distributions(fit1, fit2 = fit2)
 #'
 #' # visualize distributions underlying multiple fits
-#' plot_distributions(fit1, fits=fit_list)
+#' plot_distributions(fit1, fits = fit_list)
 #'
 #' # visualize difference between distributions underlying two fits,
 #' # use a rope interval
-#' plot_distributions_difference(fit1, fit2=fit2, rope=0.05)
+#' plot_distributions_difference(fit1, fit2 = fit2, rope = 0.05)
 #'
 #' # visualize difference between distributions underlying multiple fits
-#' plot_distributions_difference(fit1, fits=fit_list)
+#' plot_distributions_difference(fit1, fits = fit_list)
 #' }
 #'
 success_rate_class <- setClass(
@@ -180,7 +182,7 @@ success_rate_class <- setClass(
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="summary", signature(object="success_rate_class"), definition=function(object) {
+setMethod(f = "summary", signature(object = "success_rate_class"), definition = function(object) {
   # get means
   p <- mean(object@extract$p0)
   tau <- mean(object@extract$tau)
@@ -190,10 +192,14 @@ setMethod(f="summary", signature(object="success_rate_class"), definition=functi
   tau_hdi <- mcmc_hdi(object@extract$tau)
 
   # print
-  cat(sprintf("Success rate:\t%.2f +/- %.5f\t95%% HDI: [%.2f, %.2f]\n",
-              p, mcmcse::mcse(object@extract$p0)$se, p_hdi[1], p_hdi[2]))
-  cat(sprintf("Tau:\t\t%.2f +/- %.5f\t95%% HDI: [%.2f, %.2f]\n",
-              tau, mcmcse::mcse(object@extract$tau)$se, tau_hdi[1], tau_hdi[2]))
+  cat(sprintf(
+    "Success rate:\t%.2f +/- %.5f\t95%% HDI: [%.2f, %.2f]\n",
+    p, mcmcse::mcse(object@extract$p0)$se, p_hdi[1], p_hdi[2]
+  ))
+  cat(sprintf(
+    "Tau:\t\t%.2f +/- %.5f\t95%% HDI: [%.2f, %.2f]\n",
+    tau, mcmcse::mcse(object@extract$tau)$se, tau_hdi[1], tau_hdi[2]
+  ))
 })
 
 
@@ -208,7 +214,7 @@ setMethod(f="summary", signature(object="success_rate_class"), definition=functi
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="show", signature(object="success_rate_class"), definition=function(object) {
+setMethod(f = "show", signature(object = "success_rate_class"), definition = function(object) {
   # print
   show(object@fit)
 })
@@ -227,8 +233,8 @@ setMethod(f="show", signature(object="success_rate_class"), definition=function(
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot", signature(x="success_rate_class", y="missing"), definition=function(x, ...) {
-  return(plot_fit(object=x, ...))
+setMethod(f = "plot", signature(x = "success_rate_class", y = "missing"), definition = function(x, ...) {
+  return(plot_fit(object = x, ...))
 })
 
 
@@ -246,7 +252,7 @@ setMethod(f="plot", signature(x="success_rate_class", y="missing"), definition=f
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot_fit", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "plot_fit", signature(object = "success_rate_class"), definition = function(object, ...) {
   # init local varibales for CRAN check
   variable <- value <- NULL
 
@@ -258,34 +264,36 @@ setMethod(f="plot_fit", signature(object="success_rate_class"), definition=funct
     subjects <- arguments$subjects
   }
 
-  df_data <- data.frame(value=object@data$r, variable=object@data$s)
+  df_data <- data.frame(value = object@data$r, variable = object@data$s)
 
   if (!subjects) {
     mean_p <- mean(df_data$value)
 
-    df_fit <- data.frame(value=object@extract$p0)
+    df_fit <- data.frame(value = object@extract$p0)
 
     graph <- ggplot() +
-      geom_vline(xintercept=mean_p, color="#ff4e3f") +
-      geom_density(data=df_fit, aes(x=value), fill="#3182bd", alpha=0.4, color=NA) +
+      geom_vline(xintercept = mean_p, color = "#ff4e3f") +
+      geom_density(data = df_fit, aes(x = value), fill = "#3182bd", alpha = 0.4, color = NA) +
       xlim(0, 1) +
       xlab("success rate")
   } else {
-    df_data <- df_data %>% group_by(variable) %>% summarize(value=mean(value))
+    df_data <- df_data %>%
+      group_by(variable) %>%
+      summarize(value = mean(value))
 
     df_fit <- object@extract$p
     colnames(df_fit) <- seq(1:ncol(df_fit))
-    df_fit <- reshape::melt(as.data.frame(df_fit), id=NULL)
+    df_fit <- reshape::melt(as.data.frame(df_fit), id = NULL)
 
     # ncol
     n_col <- ceiling(sqrt(nrow(df_data)))
 
     # density per subject
     graph <- ggplot() +
-      geom_vline(data=df_data, aes(xintercept=value), color="#ff4e3f") +
-      geom_density(data=df_fit, aes(x=value), fill="#3182bd", alpha=0.4, color=NA) +
+      geom_vline(data = df_data, aes(xintercept = value), color = "#ff4e3f") +
+      geom_density(data = df_fit, aes(x = value), fill = "#3182bd", alpha = 0.4, color = NA) +
       xlim(0, 1) +
-      facet_wrap(~ variable, ncol=n_col) +
+      facet_wrap(~variable, ncol = n_col) +
       xlab("success rate")
   }
 
@@ -306,8 +314,8 @@ setMethod(f="plot_fit", signature(object="success_rate_class"), definition=funct
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot_trace", signature(object="success_rate_class"), definition=function(object) {
-  rstan::traceplot(object@fit, pars=c("p"), inc_warmup=TRUE)
+setMethod(f = "plot_trace", signature(object = "success_rate_class"), definition = function(object) {
+  rstan::traceplot(object@fit, pars = c("p"), inc_warmup = TRUE)
 })
 
 
@@ -324,9 +332,11 @@ setMethod(f="plot_trace", signature(object="success_rate_class"), definition=fun
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="get_parameters", signature(object="success_rate_class"), definition=function(object) {
-  df <- data.frame(p=object@extract$p0,
-                   tau=object@extract$tau)
+setMethod(f = "get_parameters", signature(object = "success_rate_class"), definition = function(object) {
+  df <- data.frame(
+    p = object@extract$p0,
+    tau = object@extract$tau
+  )
 
   return(df)
 })
@@ -345,14 +355,16 @@ setMethod(f="get_parameters", signature(object="success_rate_class"), definition
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="get_subject_parameters", signature(object="success_rate_class"), definition=function(object) {
-  df <- data.frame(p=numeric(), subject=numeric())
+setMethod(f = "get_subject_parameters", signature(object = "success_rate_class"), definition = function(object) {
+  df <- data.frame(p = numeric(), subject = numeric())
 
   n <- length(unique(object@data$s))
 
   for (i in 1:n) {
-    df_subject <- data.frame(p = object@extract$p[,i],
-                             subject = i)
+    df_subject <- data.frame(
+      p = object@extract$p[, i],
+      subject = i
+    )
 
     df <- rbind(df, df_subject)
   }
@@ -375,7 +387,7 @@ setMethod(f="get_subject_parameters", signature(object="success_rate_class"), de
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="compare_means", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "compare_means", signature(object = "success_rate_class"), definition = function(object, ...) {
   arguments <- list(...)
 
   wrong_arguments <- "The provided arguments for the compare_means function are invalid, compare_means(success_rate_class, fit2=success_rate_class) or compare_means(success_rate_class, fits=list) is required! You can also provide the rope parameter, e.g. compare_means(success_rate_class, fit2=success_rate_class, rope=numeric)."
@@ -410,7 +422,7 @@ setMethod(f="compare_means", signature(object="success_rate_class"), definition=
     # provided a list of fits
     i <- 2
     for (fit in arguments$fits) {
-      if (class(fit) != "success_rate_class") {
+      if (!("success_rate_class" %in% class(fit))) {
         stop("One of the fits in the fits list is not a valid success_rate_class object.")
       }
       y[[i]] <- fit@extract$p0
@@ -422,12 +434,12 @@ setMethod(f="compare_means", signature(object="success_rate_class"), definition=
 
   n <- length(y)
   comparison_matrix <- matrix(nrow = n, ncol = n)
-  for (i in 1:(n-1)) {
-    for (j in (i+1):n) {
+  for (i in 1:(n - 1)) {
+    for (j in (i + 1):n) {
       cat(sprintf("\n---------- Group %d vs Group %d ----------\n", i, j))
-      result <- difference(y1=y[[i]], y2=y[[j]], rope=rope, group1=i, group2=j)
-      comparison_matrix[j,i] <- result[1]
-      comparison_matrix[i,j] <- result[2]
+      result <- difference(y1 = y[[i]], y2 = y[[j]], rope = rope, group1 = i, group2 = j)
+      comparison_matrix[j, i] <- result[1]
+      comparison_matrix[i, j] <- result[2]
       cat("\n")
     }
   }
@@ -436,10 +448,10 @@ setMethod(f="compare_means", signature(object="success_rate_class"), definition=
   if (n > 2) {
     cat("-----------------------------------------")
     cat("\nProbabilities that a certain group is\nsmallest/largest or equal to all others:\n\n")
-    smallest_largest <- is_smallest_or_largest(data=y, rope=rope)
+    smallest_largest <- is_smallest_or_largest(data = y, rope = rope)
     print(smallest_largest)
     cat("\n\n")
-    return(list(comparison_matrix=comparison_matrix, smallest_largest=smallest_largest))
+    return(list(comparison_matrix = comparison_matrix, smallest_largest = smallest_largest))
   } else {
     return(comparison_matrix)
   }
@@ -460,7 +472,7 @@ setMethod(f="compare_means", signature(object="success_rate_class"), definition=
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot_means_difference", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "plot_means_difference", signature(object = "success_rate_class"), definition = function(object, ...) {
   # init local varibales for CRAN check
   value <- NULL
 
@@ -495,7 +507,7 @@ setMethod(f="plot_means_difference", signature(object="success_rate_class"), def
   } else if (!is.null(arguments$fits)) {
     i <- 2
     for (fit in arguments$fits) {
-      if (class(fit) != "success_rate_class") {
+      if (!("success_rate_class" %in% class(fit))) {
         stop("One of the fits in the fits list is not a valid success_rate_class object.")
       }
       y[[i]] <- fit@extract$p0
@@ -515,7 +527,7 @@ setMethod(f="plot_means_difference", signature(object="success_rate_class"), def
   # if no list is provided
   if (is.null(arguments$fits)) {
     # call plot difference shared function
-    graph <- plot_difference(y1=y[[1]], y2=y[[2]], rope=rope, bins=bins)
+    graph <- plot_difference(y1 = y[[1]], y2 = y[[2]], rope = rope, bins = bins)
     return(graph)
   } else {
     graphs <- list()
@@ -524,24 +536,24 @@ setMethod(f="plot_means_difference", signature(object="success_rate_class"), def
       for (j in i:n) {
         # if both are equal plot means, else plot difference
         if (i == j) {
-          df <- data.frame(value=y[[i]])
-          index <- (i-1)*n + i
+          df <- data.frame(value = y[[i]])
+          index <- (i - 1) * n + i
           graphs[[index]] <- ggplot() +
-            geom_density(data=df, aes(x=value), fill="#3182bd", color=NA, alpha=0.4) +
+            geom_density(data = df, aes(x = value), fill = "#3182bd", color = NA, alpha = 0.4) +
             xlab("probability") +
             xlim(0, 1)
         } else {
-          index1 <- (i-1)*n + j
-          graphs[[index1]] <- plot_difference(y1=y[[i]], y2=y[[j]], rope=rope, bins=bins, nrow=n)
+          index1 <- (i - 1) * n + j
+          graphs[[index1]] <- plot_difference(y1 = y[[i]], y2 = y[[j]], rope = rope, bins = bins, nrow = n)
 
-          index2 <- (j-1)*n + i
-          graphs[[index2]] <- plot_difference(y1=y[[j]], y2=y[[i]], rope=rope, bins=bins, nrow=n)
+          index2 <- (j - 1) * n + i
+          graphs[[index2]] <- plot_difference(y1 = y[[j]], y2 = y[[i]], rope = rope, bins = bins, nrow = n)
         }
       }
     }
 
     # cowplot
-    graph <- suppressWarnings(cowplot::plot_grid(plotlist=graphs, nrow=n, ncol=n, scale=0.9))
+    graph <- suppressWarnings(cowplot::plot_grid(plotlist = graphs, nrow = n, ncol = n, scale = 0.9))
     return(graph)
   }
 })
@@ -561,12 +573,12 @@ setMethod(f="plot_means_difference", signature(object="success_rate_class"), def
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot_means", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "plot_means", signature(object = "success_rate_class"), definition = function(object, ...) {
   # init local varibales for CRAN check
   group <- value <- NULL
 
   # first group data
-  df <- data.frame(value=object@extract$p0, group="1")
+  df <- data.frame(value = object@extract$p0, group = "1")
 
   # second group data
   arguments <- list(...)
@@ -579,14 +591,14 @@ setMethod(f="plot_means", signature(object="success_rate_class"), definition=fun
         fit2 <- arguments[[1]]
       }
 
-      df <- rbind(df, data.frame(value=fit2@extract$p0, group="2"))
+      df <- rbind(df, data.frame(value = fit2@extract$p0, group = "2"))
     } else if (!is.null(arguments$fits)) {
       i <- 2
       for (fit in arguments$fits) {
-        if (class(fit) != "success_rate_class") {
+        if (!("success_rate_class" %in% class(fit))) {
           stop("One of the fits in the fits list is not a valid success_rate_class object.")
         }
-        df <- rbind(df, data.frame(value=fit@extract$p0, group=as.factor(i)))
+        df <- rbind(df, data.frame(value = fit@extract$p0, group = as.factor(i)))
         i <- i + 1
       }
     }
@@ -594,21 +606,21 @@ setMethod(f="plot_means", signature(object="success_rate_class"), definition=fun
 
   # plot
   graph <- ggplot() +
-    geom_density(data=df, aes(x=value, fill=group), color=NA, alpha=0.4) +
+    geom_density(data = df, aes(x = value, fill = group), color = NA, alpha = 0.4) +
     xlab("probability") +
     xlim(0, 1)
 
   n_groups <- max(as.numeric(df$group))
   if (n_groups == 2) {
     graph <- graph +
-      scale_fill_manual(values=c("#3182bd", "#ff4e3f"))
+      scale_fill_manual(values = c("#3182bd", "#ff4e3f"))
   } else if (n_groups > 2) {
     graph <- graph +
       scale_fill_hue()
   } else {
     graph <- graph +
-      scale_fill_manual(values=c("#3182bd")) +
-      theme(legend.position="none")
+      scale_fill_manual(values = c("#3182bd")) +
+      theme(legend.position = "none")
   }
 
   return(suppressWarnings(graph))
@@ -629,7 +641,7 @@ setMethod(f="plot_means", signature(object="success_rate_class"), definition=fun
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="compare_distributions", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "compare_distributions", signature(object = "success_rate_class"), definition = function(object, ...) {
   arguments <- list(...)
 
   wrong_arguments <- "The provided arguments for the compare_distributions function are invalid, compare_distributions(success_rate_class, fit2=success_rate_class) or compare_distributions(success_rate_class, fits=list) is required!. You can also provide the rope parameter, e.g. compare_distributions(success_rate_class, fit2=success_rate_class, rope=numeric)."
@@ -650,7 +662,7 @@ setMethod(f="compare_distributions", signature(object="success_rate_class"), def
   n <- 100000
   p0 <- mean(object@extract$p0)
   tau <- mean(object@extract$tau)
-  y[[1]] <- stats::rbeta(n, p0*tau, (1 - p0)*tau)
+  y[[1]] <- stats::rbeta(n, p0 * tau, (1 - p0) * tau)
 
   # second group data
   if (!is.null(arguments$fit2) || class(arguments[[1]])[1] == "success_rate_class") {
@@ -662,17 +674,17 @@ setMethod(f="compare_distributions", signature(object="success_rate_class"), def
     }
     p0 <- mean(fit2@extract$p0)
     tau <- mean(fit2@extract$tau)
-    y[[2]] <- stats::rbeta(n, p0*tau, (1 - p0)*tau)
+    y[[2]] <- stats::rbeta(n, p0 * tau, (1 - p0) * tau)
   } else if (!is.null(arguments$fits)) {
     # provided a list of fits
     i <- 2
     for (fit in arguments$fits) {
-      if (class(fit) != "success_rate_class") {
+      if (!("success_rate_class" %in% class(fit))) {
         stop("One of the fits in the fits list is not a valid success_rate_class object.")
       }
       p0 <- mean(fit@extract$p0)
       tau <- mean(fit@extract$tau)
-      y[[i]] <- stats::rbeta(n, p0*tau, (1 - p0)*tau)
+      y[[i]] <- stats::rbeta(n, p0 * tau, (1 - p0) * tau)
       i <- i + 1
     }
   } else {
@@ -681,12 +693,12 @@ setMethod(f="compare_distributions", signature(object="success_rate_class"), def
 
   n <- length(y)
   comparison_matrix <- matrix(nrow = n, ncol = n)
-  for (i in 1:(n-1)) {
-    for (j in (i+1):n) {
+  for (i in 1:(n - 1)) {
+    for (j in (i + 1):n) {
       cat(sprintf("\n---------- Group %d vs Group %d ----------\n", i, j))
-      result <- difference(y1=y[[i]], y2=y[[j]], rope=rope, group1=i, group2=j)
-      comparison_matrix[j,i] <- result[1]
-      comparison_matrix[i,j] <- result[2]
+      result <- difference(y1 = y[[i]], y2 = y[[j]], rope = rope, group1 = i, group2 = j)
+      comparison_matrix[j, i] <- result[1]
+      comparison_matrix[i, j] <- result[2]
       cat("\n")
     }
   }
@@ -695,10 +707,10 @@ setMethod(f="compare_distributions", signature(object="success_rate_class"), def
   if (n > 2) {
     cat("-----------------------------------------")
     cat("\nProbabilities that a certain group is\nsmallest/largest or equal to all others:\n\n")
-    smallest_largest <- is_smallest_or_largest(data=y, rope=rope)
+    smallest_largest <- is_smallest_or_largest(data = y, rope = rope)
     print(smallest_largest)
     cat("\n\n")
-    return(list(comparison_matrix=comparison_matrix, smallest_largest=smallest_largest))
+    return(list(comparison_matrix = comparison_matrix, smallest_largest = smallest_largest))
   } else {
     return(comparison_matrix)
   }
@@ -719,7 +731,7 @@ setMethod(f="compare_distributions", signature(object="success_rate_class"), def
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot_distributions", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "plot_distributions", signature(object = "success_rate_class"), definition = function(object, ...) {
   # init local varibales for CRAN check
   group <- x <- y <- NULL
 
@@ -728,8 +740,8 @@ setMethod(f="plot_distributions", signature(object="success_rate_class"), defini
   betas <- vector()
   p0 <- mean(object@extract$p0)
   tau <- mean(object@extract$tau)
-  alphas[[1]] <- p0*tau
-  betas[[1]] <- (1 - p0)*tau
+  alphas[[1]] <- p0 * tau
+  betas[[1]] <- (1 - p0) * tau
 
   # second group data
   arguments <- list(...)
@@ -743,18 +755,18 @@ setMethod(f="plot_distributions", signature(object="success_rate_class"), defini
       }
       p0 <- mean(fit2@extract$p0)
       tau <- mean(fit2@extract$tau)
-      alphas[[2]] <- p0*tau
-      betas[[2]] <- (1 - p0)*tau
+      alphas[[2]] <- p0 * tau
+      betas[[2]] <- (1 - p0) * tau
     } else if (!is.null(arguments$fits)) {
       i <- 2
       for (fit in arguments$fits) {
-        if (class(fit) != "success_rate_class") {
+        if (!("success_rate_class" %in% class(fit))) {
           stop("One of the fits in the fits list is not a valid success_rate_class object.")
         }
         p0 <- mean(fit@extract$p0)
         tau <- mean(fit@extract$tau)
-        alphas[[i]] <- p0*tau
-        betas[[i]] <- (1 - p0)*tau
+        alphas[[i]] <- p0 * tau
+        betas[[i]] <- (1 - p0) * tau
         i <- i + 1
       }
     }
@@ -762,34 +774,37 @@ setMethod(f="plot_distributions", signature(object="success_rate_class"), defini
 
   # calculate data points
   step <- 1 / 1000
-  df <- data.frame(x=numeric(), y=numeric(), group=factor())
+  df <- data.frame(x = numeric(), y = numeric(), group = factor())
   n_groups <- length(alphas)
   for (i in 1:n_groups) {
-    df_group <- data.frame(x = seq(0, 1, step),
-                           y = stats::dbeta(seq(0, 1, step),
-                                            shape1 = alphas[i],
-                                            shape2 = betas[i]),
-                           group=as.factor(i))
+    df_group <- data.frame(
+      x = seq(0, 1, step),
+      y = stats::dbeta(seq(0, 1, step),
+        shape1 = alphas[i],
+        shape2 = betas[i]
+      ),
+      group = as.factor(i)
+    )
 
     df <- rbind(df, df_group)
   }
 
   # plot
   graph <- ggplot() +
-    geom_area(data=df, aes(x=x, y=y, fill=group), alpha=0.4, position="identity") +
+    geom_area(data = df, aes(x = x, y = y, fill = group), alpha = 0.4, position = "identity") +
     xlab("probability") +
     ylab("density")
 
   if (n_groups == 2) {
     graph <- graph +
-      scale_fill_manual(values=c("#3182bd", "#ff4e3f"))
+      scale_fill_manual(values = c("#3182bd", "#ff4e3f"))
   } else if (n_groups > 2) {
     graph <- graph +
       scale_fill_hue()
   } else {
     graph <- graph +
-      scale_fill_manual(values=c("#3182bd")) +
-      theme(legend.position="none")
+      scale_fill_manual(values = c("#3182bd")) +
+      theme(legend.position = "none")
   }
 
   return(suppressWarnings(graph))
@@ -810,7 +825,7 @@ setMethod(f="plot_distributions", signature(object="success_rate_class"), defini
 #' # along with an example of how to use this function
 #' ?success_rate_class
 #'
-setMethod(f="plot_distributions_difference", signature(object="success_rate_class"), definition=function(object, ...) {
+setMethod(f = "plot_distributions_difference", signature(object = "success_rate_class"), definition = function(object, ...) {
   # init local varibales for CRAN check
   value <- NULL
 
@@ -834,7 +849,7 @@ setMethod(f="plot_distributions_difference", signature(object="success_rate_clas
   n <- 100000
   p0 <- mean(object@extract$p0)
   tau <- mean(object@extract$tau)
-  y[[1]] <- stats::rbeta(n, p0*tau, (1 - p0)*tau)
+  y[[1]] <- stats::rbeta(n, p0 * tau, (1 - p0) * tau)
 
   # second group data
   if (!is.null(arguments$fit2) || class(arguments[[1]])[1] == "success_rate_class") {
@@ -846,16 +861,16 @@ setMethod(f="plot_distributions_difference", signature(object="success_rate_clas
     }
     p0 <- mean(fit2@extract$p0)
     tau <- mean(fit2@extract$tau)
-    y[[2]] <- stats::rbeta(n, p0*tau, (1 - p0)*tau)
+    y[[2]] <- stats::rbeta(n, p0 * tau, (1 - p0) * tau)
   } else if (!is.null(arguments$fits)) {
     i <- 2
     for (fit in arguments$fits) {
-      if (class(fit) != "success_rate_class") {
+      if (!("success_rate_class" %in% class(fit))) {
         stop("One of the fits in the fits list is not a valid success_rate_class object.")
       }
       p0 <- mean(fit@extract$p0)
       tau <- mean(fit@extract$tau)
-      y[[i]] <- stats::rbeta(n, p0*tau, (1 - p0)*tau)
+      y[[i]] <- stats::rbeta(n, p0 * tau, (1 - p0) * tau)
       i <- i + 1
     }
   } else {
@@ -871,7 +886,7 @@ setMethod(f="plot_distributions_difference", signature(object="success_rate_clas
   # if no list is provided
   if (is.null(arguments$fits)) {
     # call plot difference shared function
-    graph <- plot_difference(y1=y[[1]], y2=y[[2]], rope=rope, bins=bins)
+    graph <- plot_difference(y1 = y[[1]], y2 = y[[2]], rope = rope, bins = bins)
     return(graph)
   } else {
     graphs <- list()
@@ -880,24 +895,24 @@ setMethod(f="plot_distributions_difference", signature(object="success_rate_clas
       for (j in i:n) {
         # if both are equal plot samples, else plot difference
         if (i == j) {
-          df <- data.frame(value=y[[i]])
-          index <- (i-1)*n + i
+          df <- data.frame(value = y[[i]])
+          index <- (i - 1) * n + i
           graphs[[index]] <- ggplot() +
-            geom_density(data=df, aes(x=value), fill="#3182bd", color=NA, alpha=0.4) +
+            geom_density(data = df, aes(x = value), fill = "#3182bd", color = NA, alpha = 0.4) +
             xlab("probability") +
             xlim(0, 1)
         } else {
-          index1 <- (i-1)*n + j
-          graphs[[index1]] <- plot_difference(y1=y[[i]], y2=y[[j]], rope=rope, bins=bins, nrow=n)
+          index1 <- (i - 1) * n + j
+          graphs[[index1]] <- plot_difference(y1 = y[[i]], y2 = y[[j]], rope = rope, bins = bins, nrow = n)
 
-          index2 <- (j-1)*n + i
-          graphs[[index2]] <- plot_difference(y1=y[[j]], y2=y[[i]], rope=rope, bins=bins, nrow=n)
+          index2 <- (j - 1) * n + i
+          graphs[[index2]] <- plot_difference(y1 = y[[j]], y2 = y[[i]], rope = rope, bins = bins, nrow = n)
         }
       }
     }
 
     # cowplot
-    graph <- suppressWarnings(cowplot::plot_grid(plotlist=graphs, nrow=n, ncol=n, scale=0.9))
+    graph <- suppressWarnings(cowplot::plot_grid(plotlist = graphs, nrow = n, ncol = n, scale = 0.9))
     return(graph)
   }
 })
