@@ -17,23 +17,15 @@ group1_part2 <- data %>% filter(group == 1 & part == 2)
 group2_part2 <- data %>% filter(group == 2 & part == 2)
 
 ## ---- message=FALSE, warning=FALSE, results = 'hide'--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-# prior
-beta_prior <- b_prior(family="normal", pars=c(0, 1))
-
-# attach priors to relevant parameters
-priors <- list(c("mu_b", beta_prior))
-
-
+# fit
 fit1 <- b_linear(x=group1_part2$sequence,
                  y=group1_part2$response,
                  s=group1_part2$subject,
-                 priors=priors,
                  iter=200, warmup=100, chains=1)
 
 fit2 <- b_linear(x=group2_part2$sequence,
                  y=group2_part2$response,
                  s=group2_part2$subject,
-                 priors=priors,
                  iter=200, warmup=100, chains=1)
 
 ## ---- message=FALSE, warning=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
